@@ -1,4 +1,4 @@
-use std::{mem::take};
+use std::mem::take;
 
 use proc_macro::{Delimiter, Spacing, TokenTree};
 
@@ -227,13 +227,16 @@ pub fn akin(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
     let mut vars: Vec<(String, Vec<String>)> = Vec::with_capacity(2);
     //panic!("Tokens: {input:#?}");
     let mut tokens = input.into_iter();
-    
+
     let mut first = tokens.next().expect("akin: expected code to duplicate");
     let mut second = tokens.next().expect("akin: expected code to duplicate");
     while matches!(&first, TokenTree::Ident(id) if id.to_string() == "let")
         && matches!(&second, TokenTree::Punct(p) if p.as_char() == '&')
     {
         vars.push(parse_var(&mut tokens, &vars));
+        // Reverse vars ordering to fix replace bug
+        vars.sort_unstable_by(|(a, _), (b, _)| a.cmp(b).reverse());
+
         first = tokens.next().expect("akin: expected code to duplicate");
         second = tokens.next().expect("akin: expected code to duplicate");
     }
@@ -245,6 +248,7 @@ pub fn akin(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
         &mut previous,
     );
     let out_raw = tokens.fold(init, |acc, tt| fold_tt(acc, tt, &mut previous));
+    
     let out = duplicate(&out_raw, &vars);
 
     //let tokens = format!("proc_macro: {:#?}", input.into_iter().collect::<Vec<_>>());
@@ -276,20 +280,20 @@ fn parse_var(
         let mut add = String::new();
 
         let mut stream = group.stream().into_iter();
-        
+
         while let Some(var) = stream.next() {
             let mut var = var;
             let mut new = String::new();
             while !matches!(&var, TokenTree::Punct(p) if p.as_char() == ',') {
                 new += &match &var {
                     TokenTree::Group(g) if g.delimiter() == Delimiter::Brace => g
-                    .stream()
-                    .into_iter()
-                    .fold(String::new(), |acc, tt| fold_tt(acc, tt, &mut prev)),
+                        .stream()
+                        .into_iter()
+                        .fold(String::new(), |acc, tt| fold_tt(acc, tt, &mut prev)),
 
                     _ => var.to_string(),
                 };
-                
+
                 if let Some(v) = stream.next() {
                     var = v;
                 } else {
@@ -303,27 +307,6 @@ fn parse_var(
                 values.push(duplicate(&(take(&mut add) + &new), vars));
             }
         }
-        
-        /*
-        for var in group.stream() {
-            let new = match &var {
-                // Case {group} => Variable is code, braces need to be skipped
-                // Case punct   => Variable is punctuation, it will be grouped with the next variable. Workaround for characters like '-' or '!'
-                // Case _       => Variable is a value, it is printed normally.
-                TokenTree::Group(g) if g.delimiter() == Delimiter::Brace => g
-                    .stream()
-                    .into_iter()
-                    .fold(String::new(), |acc, tt| fold_tt(acc, tt, &mut prev)),
-                _ => var.to_string(),
-            };
-
-            if new == "NONE" {
-                values.push(String::new())
-            } else if new != "," {
-                values.push(duplicate(&(take(&mut add) + &new), vars));
-            }
-        }
-        */
     } else {
         let fold = group
             .stream()
@@ -369,14 +352,25 @@ fn get_used_vars<'a>(
 ) -> (Vec<&'a (String, Vec<String>)>, usize) {
     let mut used = Vec::with_capacity(vars.len());
     let mut times = 0;
-
+    let mut indices = std::collections::HashSet::new();
     for var in vars {
+        let matches = stream.match_indices(&var.0);
+        for (m, _) in matches {
+            if !indices.contains(&m) {
+                indices.insert(m);
+                used.push(var);
+                times = times.max(var.1.len());
+                break;
+            }
+        }
+        /*
         if stream.contains(&var.0) {
             used.push(var);
             times = times.max(var.1.len());
         }
+        */
     }
-
+    
     (used, times)
 }
 
@@ -399,14 +393,15 @@ fn fold_tt(a: String, tt: TokenTree, prev: &mut TokenTree) -> String {
         format!("{a}{start}{group}{end}")
     } else if matches!(&tt, TokenTree::Punct(p) if p.as_char() == '~') {
         a // skip character
-    } else if matches!(&prev, TokenTree::Punct(p) if p.spacing() == Spacing::Joint || matches!(p.as_char(), '*' | '~')) {
+    } else if matches!(&prev, TokenTree::Punct(p) if p.spacing() == Spacing::Joint || matches!(p.as_char(), '*' | '~'))
+    {
         // Case '*' => To make variable formatting simpler ('*var' instead of '* var')
         // Case '~' => Behaviour of the '~' modifier
         format!("{a}{tt}")
     } else {
         format!("{a} {tt}")
     };
-    
+
     *prev = tt;
     ret
 }
