@@ -126,7 +126,7 @@ fn readme_example() {
     trait Sqrt {
         fn dumb_sqrt(self) -> Result<f64, &'static str>;
     }
-    
+
     akin! {
         let &int_type = [i64, u64];
         let &negative_check = [
@@ -137,17 +137,17 @@ fn readme_example() {
             },
             NONE
         ];
-        
+
         let &num = [1,     2,    3,  4];
         let &res = [1., 1.41, 1.73,  2.];
         let &branch = {
             *num => Ok(*res),
         };
-        
+
         impl Sqrt for *int_type {
             fn dumb_sqrt(self) -> Result<f64, &'static str> {
                 *negative_check
-                
+
                 match self {
                     *branch
                     _ => Err("Sqrt of num not in [1, 4]")
@@ -162,3 +162,35 @@ fn readme_example() {
     assert_eq!(3i64.dumb_sqrt(), Ok(1.73));
     assert_eq!((-5i64).dumb_sqrt(), Err("Sqrt of negative number"));
 }
+
+#[test]
+fn var_replace_global() {
+    akin! {
+        let &foo = [wrong];
+        let &foobar = [correct];
+
+        assert_eq!("*foobar", "correct");
+    }
+}
+
+#[test]
+fn var_replace_value() {
+    akin! {
+        let &foo = [wrong];
+        let &foobar = [correct];
+        let &bar = [*foobar];
+
+        assert_eq!("*bar", "correct");
+    }
+}
+
+#[test]
+fn var_replace_code() {
+    akin! {
+        let &foo = [wrong];
+        let &foobar = ["correct"];
+        let &bar = { *foobar };
+
+        assert_eq!(*bar, "correct");
+    }
+}
